@@ -711,14 +711,17 @@ class Agent(Insight, Channel, Catalog, Dataset):
         user_id = self.__get_user_by_email(user_email)
 
         channel_id = self.get_channel(channel_slug)["id"]
-        self.__add_user_to_ch(channel_id, user_id, role)
+        try:
+            self.__add_user_to_ch(channel_id, user_id, role)
+        except:
+            logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(user_email))
 
     def __add_user_to_ch(self, channel_id, user_id, role="FOLLOWER"):
 
         data = {
             "userId":user_id,
             "role":role,
-            "mute":"none"
+            "mute": "none"
         }
 
         s = requests.Session()
@@ -898,7 +901,7 @@ class Askdata(SignUp):
                 datasetSlug = dataset_slug
 
         if(replace):
-            url = self.base_url + "/smartbot/agent-slugs/{}/datasets/{}/parquet".format(agentSlug, datasetSlug)
+            url = self.base_url + "/smartbot/agent-slugs/{}/dataset-slugs/{}/parquet".format(agentSlug, datasetSlug)
 
             s = requests.Session()
             s.keep_alive = False
@@ -915,7 +918,7 @@ class Askdata(SignUp):
             dataset = response.json()
             dataset_id = dataset["id"]
         else:
-            url = self.base_url + "/smartbot/agent-slugs/{}/datasets/{}/parquet".format(agentSlug, datasetSlug)
+            url = self.base_url + "/smartbot/agent-slugs/{}/dataset-slugs/{}/parquet".format(agentSlug, datasetSlug)
 
             s = requests.Session()
             s.keep_alive = False
